@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020 CERN.
-# Copyright (C) 2020 Northwestern University.
+# Copyright (C) 2020-2021 CERN.
+# Copyright (C) 2020-2021 Northwestern University.
 #
-# Invenio-Records-Resources is free software; you can redistribute it and/or
+# Invenio-Drafts-Resources is free software; you can redistribute it and/or
 # modify it under the terms of the MIT License; see LICENSE file for more
 # details.
 
@@ -15,12 +15,17 @@ Test to add:
 - Read with missing pid
 """
 
+from io import BytesIO
+
 import pytest
+from invenio_files_rest.errors import InvalidOperationError
 from invenio_pidstore.errors import PIDDoesNotExistError, PIDUnregistered
 from invenio_pidstore.models import PIDStatus
 from marshmallow.exceptions import ValidationError
 from sqlalchemy.orm.exc import NoResultFound
 
+from .utils import create_and_publish
+
 #
 # Operations tests
 #
@@ -104,6 +109,45 @@ def test_update_draft_invalid_field(app, service, identity_simple, input_data):
     assert updated_draft_dict['errors'][0]['field'] == 'metadata.title'
 
 
+def add_file_to_draft(file_service, draft_id, file_id, identity):
+    """Add a file to the record."""
+    file_service.init_files(draft_id, identity, data=[{'key': file_id}])
+    file_service.set_file_content(
+        draft_id, file_id, identity, BytesIO(b'test file content')
+    )
+    result = file_service.commit_file(draft_id, file_id, identity)
+    return result
+
+
+def test_update_draft_files_enabled_error_cases(
+        app, service, file_service, identity_simple, input_data):
+    # Test files.enabled = True when no files
+    draft = service.create(identity_simple, input_data)
+    input_data["files"] = {"enabled": True}
+
+    updated_draft = service.update_draft(draft.id, identity_simple, input_data)
+
+    updated_draft_dict = updated_draft.to_dict()
+    assert updated_draft_dict['errors'][0]['field'] == 'files.enabled'
+    files_missing_msg = updated_draft_dict['errors'][0]['messages']
+    assert files_missing_msg is not None
+    assert updated_draft_dict["files"]["enabled"] is True
+
+    # Test setting files.enabled = False when files present
+    input_data["files"] = {"enabled": True}
+    draft = service.create(identity_simple, input_data)
+    add_file_to_draft(file_service, draft.id, "file.txt", identity_simple)
+    input_data["files"] = {"enabled": False}
+
+    updated_draft = service.update_draft(draft.id, identity_simple, input_data)
+
+    updated_draft_dict = updated_draft.to_dict()
+    assert updated_draft_dict['errors'][0]['field'] == 'files.enabled'
+    files_present_msg = updated_draft_dict['errors'][0]['messages']
+    assert files_present_msg != files_missing_msg
+    assert updated_draft_dict["files"]["enabled"] is True
+
+
 def test_delete_draft(app, service, identity_simple, input_data):
     draft = service.create(identity_simple, input_data)
     assert draft.id
@@ -117,26 +161,13 @@ def test_delete_draft(app, service, identity_simple, input_data):
         delete_draft = service.read_draft(draft.id, identity_simple)
 
 
-def _create_and_publish(service, input_data, identity_simple):
-    """Creates a draft and publishes it."""
-    # Cannot create with record service due to the lack of versioning
-    draft = service.create(identity_simple, input_data)
-
-    record = service.publish(draft.id, identity_simple)
-
-    assert record.id == draft.id
-    assert record._record.revision_id == 1
-
-    return record
-
-
 def test_publish_draft(app, service, identity_simple, input_data):
     """Test draft publishing of a non-existing record.
 
     Note that the publish action requires a draft to be created first.
     """
     # Needs `app` context because of invenio_access/permissions.py#166
-    record = _create_and_publish(service, input_data, identity_simple)
+    record = create_and_publish(service, identity_simple, input_data)
     assert record._record.pid.status == PIDStatus.REGISTERED
     assert record._record.parent.pid.status == PIDStatus.REGISTERED
 
@@ -187,6 +218,31 @@ def test_fail_to_publish_invalid_draft(app, service, identity_simple):
         record = service.read(draft.id, identity_simple)
 
 
+def test_fail_to_publish_draft_with_no_files(
+        app, service, file_service, identity_simple, input_data):
+    input_data["files"] = {"enabled": True}
+    draft = service.create(identity_simple, input_data)
+
+    with pytest.raises(ValidationError) as e:
+        service.publish(draft.id, identity_simple)
+
+    assert e.value.field_name == 'files.enabled'
+    files_missing_msg = e.value.messages
+    assert files_missing_msg is not None
+
+
+def test_fail_to_add_files_to_draft_with_files_disabled(
+        app, service, file_service, identity_simple, input_data):
+    # NOTE: It is impossible to publish a draft with files but
+    #       files.enabled = False, because can't set files.enabled = False
+    #       in that case (as seen in test above) and files can't be
+    #       added if files.enabled = False as we confirm below:
+    draft = service.create(identity_simple, input_data)
+
+    with pytest.raises(InvalidOperationError):
+        add_file_to_draft(file_service, draft.id, "file.txt", identity_simple)
+
+
 #
 # Flow tests (Note that operations are tested above
 # therefore these tests do not assert their output)
@@ -199,7 +255,7 @@ def test_create_publish_new_revision(app, service, identity_simple,
     This tests the `edit` service method.
     """
     # Needs `app` context because of invenio_access/permissions.py#166
-    record = _create_and_publish(service, input_data, identity_simple)
+    record = create_and_publish(service, identity_simple, input_data)
     recid = record.id
 
     # Create new draft of said record
@@ -238,7 +294,7 @@ def test_mutiple_edit(app, service, identity_simple, input_data):
     This tests the `edit` service method.
     """
     # Needs `app` context because of invenio_access/permissions.py#166
-    record = _create_and_publish(service, input_data, identity_simple)
+    record = create_and_publish(service, identity_simple, input_data)
     recid = record.id
 
     # Create new draft of said record
@@ -267,7 +323,7 @@ def test_create_publish_new_version(app, service, identity_simple,
 
     This tests the `new_version` service method.
     """
-    record = _create_and_publish(service, input_data, identity_simple)
+    record = create_and_publish(service, identity_simple, input_data)
     recid = record.id
 
     # Create new version
@@ -278,6 +334,10 @@ def test_create_publish_new_version(app, service, identity_simple,
     assert draft._record.pid.status == PIDStatus.NEW
     assert draft._record.parent.pid.status == PIDStatus.REGISTERED
 
+    # Re-disable files
+    input_data["files"] = {"enabled": False}
+    draft = service.update_draft(draft.id, identity_simple, input_data)
+
     # Publish it
     record_2 = service.publish(draft.id, identity_simple)
 
@@ -288,23 +348,26 @@ def test_create_publish_new_version(app, service, identity_simple,
     assert record_2['id'] != record['id']
 
 
-def test_read_latest_version(app, service, identity_simple,
-                             input_data):
+def test_read_latest_version(app, service, identity_simple, input_data):
     """Test read the latest version of a record.
 
     This tests the `read_latest` service method.
     """
-    record = _create_and_publish(service, input_data, identity_simple)
+    record = create_and_publish(service, identity_simple, input_data)
     recid = record.id
 
     # Create new version
     draft = service.new_version(recid, identity_simple)
+
+    # Re-disable files
+    input_data["files"] = {"enabled": False}
+    draft = service.update_draft(draft.id, identity_simple, input_data)
+
     # Publish it
     record_2 = service.publish(draft.id, identity_simple)
     recid_2 = record_2.id
 
     latest = service.read_latest(recid, identity_simple)
     assert latest['id'] == recid_2
-
     latest = service.read_latest(recid_2, identity_simple)
     assert latest['id'] == recid_2
